@@ -148,7 +148,9 @@ wxWindow* wxGetTopLevelParent(wxWindow *win)
 #    include "gdk/gdkprivate.h"
 #if wxCHECK_VERSION(2, 8, 0)
 #ifdef __WXGTK20__
-#if  wxCHECK_VERSION(2, 9, 0)
+#if  wxCHECK_VERSION(3, 0, 0) || wxCHECK_VERSION(3, 0, 1)
+#include <gtk/gtk.h>
+#elif  wxCHECK_VERSION(2, 9, 0)
 #include <gtk/gtk.h>
 #include <wx/gtk/private/win_gtk.h>
 #else
