@@ -40,7 +40,7 @@ namespace GNC {
 			static void FreeInstance();
 
 			virtual void ProcessSync(IComando*, bool autodelete, bool update = true, GNC::INotificadorProgreso* pNotifier = NULL) = 0;
-			virtual void ProcessAsync(std::string descr, IComando*, void* owner) = 0;
+			virtual void ProcessAsync(const std::string& descr, IComando*, void* owner) = 0;
 			virtual void AbortarComando(long threadId, bool sincrono = true) = 0;
 			virtual void AbortarComandosDeOwner(void* owner) = 0;
 			virtual void AbortarComandosDeOwnerAsincrono(void* owner) = 0;
