@@ -41,7 +41,7 @@ namespace GIL {
 			typedef struct TImageFile {
 				void* pixelData;
 				int width;
-				int heigh;
+				int heigth;
 				int samplesPerPixel;
 				std::string photometricInterpretation;
 				int bitsAllocated;
@@ -54,25 +54,25 @@ namespace GIL {
 				bool recompress;
 
 				//configuration for rgbFiles uncompressed...
-				TImageFile(void* pixelData, const int with, const int heigh)
+				TImageFile(void* pixelData, const int with, const int heigth)
 				{
-					Init(pixelData, with, heigh,3,"RGB",8,8,7,0,0,1,1,true);					
+					Init(pixelData, with, heigth, 3, "RGB", 8, 8, 7, 0, 0, 1, 1, true);					
 				}
 
-				TImageFile(void* pixelData, const int width, const int heigh, const int samplesPerPixel, const std::string& photometricInterpretation, 
+				TImageFile(void* pixelData, const int width, const int heigth, const int samplesPerPixel, const std::string& photometricInterpretation, 
 					const int bitsAllocated, const int bitsStored, const int highBit, const int pixelRepr, const int planarConf, const int pixAspectH, 
 					const int pixAspectV, const bool recompress) 
 				{
-					Init(pixelData, width, heigh, samplesPerPixel, photometricInterpretation, bitsAllocated, bitsStored, highBit, pixelRepr,planarConf, pixAspectH, pixAspectV, recompress);
+					Init(pixelData, width, heigth, samplesPerPixel, photometricInterpretation, bitsAllocated, bitsStored, highBit, pixelRepr,planarConf, pixAspectH, pixAspectV, recompress);
 				}
 				
-				void Init(void* pixelData, const int width, const int heigh, const int samplesPerPixel, const std::string& photometricInterpretation, 
+				void Init(void* pixelData, const int width, const int heigth, const int samplesPerPixel, const std::string& photometricInterpretation, 
 					const int bitsAllocated, const int bitsStored, const int highBit, const int pixelRepr, const int planarConf, const int pixAspectH, 
 					const int pixAspectV, const bool recompress) 
 				{
 					this->pixelData = pixelData;
 					this->width = width;
-					this->heigh = heigh;
+					this->heigth = heigth;
 					this->samplesPerPixel = samplesPerPixel;
 					this->photometricInterpretation = photometricInterpretation;
 					this->bitsAllocated = bitsAllocated;
