@@ -34,13 +34,13 @@ namespace GNC {
 			
 
 			/* tag syntax is the same as defined in api/dicom/dcmdictionary.h   gggg|eeee*/
-			virtual std::string GetTagValue(GNC::GCS::Contexto3D* c, const std::string& key, const std::string& defValue = "");
+			virtual std::string GetTagValue(GNC::GCS::Contexto3D* c, const std::string& key, const std::string& defValue = "", const std::string& format ="");
 
 			//el comportamiento por defecto de las anotaciones con posicion es el mismo que las de sin posicion
 			//si se desean pueden sobreescribirse
 			virtual std::string GetPositionAnnotation(GNC::GCS::Contexto3D* c, const GNC::GCS::Vector3D& wP);
 		protected:
-
+			std::string FormatTag(const std::string& value, const std::string& format);
 			std::string GetFloatingPointTagWithPrecision(const std::string& key, const std::string& defValue, int precision);
 			bool ContainsTag(const std::string& key);
 
