@@ -591,6 +591,23 @@ namespace GNC {
 				return (ProyeccionOrtogonalSobreRecta(p0, p1) - (*this)).Norma2();
 			}
 
+			/* Devuelve el cuadrado de la distancia del punto a la segmento de p0 y p1 */
+			inline TComp DistanciaASegmentoCuadrado(const Vector& p0, const Vector& p1) const {
+				Vector vi = ProyeccionOrtogonalSobreRecta(p0, p1);
+				Vector pm = p0.PuntoMedio(p1);
+				if (vi.DistanciaEuclideaCuadrado(pm) > p0.DistanciaEuclideaCuadrado(pm)) {
+					return std::min(this->DistanciaEuclideaCuadrado(p0), this->DistanciaEuclideaCuadrado(p1));
+				}
+				else {
+					return this->DistanciaEuclideaCuadrado(vi);
+				}
+			}
+
+			/* Devuelve el cuadrado de la distancia del punto a la segmento de p0 y p1 */
+			inline TComp DistanciaASegmento(const Vector& p0, const Vector& p1) const {
+				return std::sqrt(this->DistanciaASegmentoCuadrado(p0, p1));
+			}
+
 			/* Devuelve el cuadrado de la distancia del punto a la recta definida por p0 y p1 */
 			inline TComp DistanciaARectaCuadrado(const Vector& p0, const Vector& p1) const {
 				return (ProyeccionOrtogonalSobreRecta(p0, p1) - (*this)).Norma2Cuadrado();
