@@ -3,7 +3,7 @@
 *  $Id: clouduploadcommand.cpp $
 *  Ginkgo CADx Project
 *
-*  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+*  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
@@ -24,6 +24,7 @@
 #include <api/controllers/ipacscontroller.h>
 #include <api/controllers/icontroladorlog.h>
 #include <api/controllers/icommandcontroller.h>
+#include <main/controllers/configurationcontroller.h>
 #include <api/controllers/ieventscontroller.h>
 #include <eventos/mensajes.h>
 #include <api/internationalization/internationalization.h>
@@ -37,7 +38,6 @@
 #include <wx/tarstrm.h>
 #include <wx/zstream.h>
 #include <wx/wfstream.h>
-#include <wx/wxhttpengine/httpbuilder.h>
 
 #define CLOUD_PROTOCOL_VERSION "1.1"
 ////helper...
@@ -221,16 +221,15 @@ void GNC::GCS::CloudCommand::doGet(GNC::GCS::CloudGetCommandParams* pParams) {
 		curl_easy_setopt(curl, CURLOPT_USERAGENT, userAgent.str().c_str());
 
 		//proxy settings
-		wxProxySettings settings;
-		settings.ProxySettingsLoadGeneral();
-		if (settings.m_bUseProxy) {
-			curl_easy_setopt(curl, CURLOPT_PROXY, std::string(settings.m_strProxyHostname.ToUTF8()).c_str());
-			curl_easy_setopt(curl, CURLOPT_PROXYPORT, settings.m_nProxyPort);
-			if (settings.m_bRequiresAuth) {
-				curl_easy_setopt(curl, CURLOPT_PROXYUSERNAME,std::string(settings.m_strProxyUsername.ToUTF8()).c_str());
-				curl_easy_setopt(curl, CURLOPT_PROXYPASSWORD, std::string(settings.m_strProxyPassword.ToUTF8()).c_str());
+		GNC::GCS::ProxySettings settings = GNC::GCS::ConfigurationController::Instance()->GetProxySettings();
+		if (settings.useProxy) {
+			curl_easy_setopt(curl, CURLOPT_PROXY, settings.hostName.c_str());
+			curl_easy_setopt(curl, CURLOPT_PROXYPORT, settings.port);
+			if (settings.requiresAuth) {
+				curl_easy_setopt(curl, CURLOPT_PROXYUSERNAME, settings.userName.c_str());
+				curl_easy_setopt(curl, CURLOPT_PROXYPASSWORD, settings.password.c_str());
 			}
-			curl_easy_setopt(curl, CURLOPT_NOPROXY, std::string(settings.m_strProxyExceptions.ToUTF8()).c_str());
+			curl_easy_setopt(curl, CURLOPT_NOPROXY, settings.exceptions.c_str());
 		}
 
 		curl_easy_setopt(curl, CURLOPT_HTTPGET, TRUE);
@@ -348,16 +347,15 @@ void GNC::GCS::CloudCommand::doFind(GNC::GCS::CloudFindCommandParams* pParams) {
 		curl_easy_setopt(curl, CURLOPT_USERAGENT, userAgent.str().c_str());
 
 		//proxy settings
-		wxProxySettings settings;
-		settings.ProxySettingsLoadGeneral();
-		if (settings.m_bUseProxy) {
-			curl_easy_setopt(curl, CURLOPT_PROXY, std::string(settings.m_strProxyHostname.ToUTF8()).c_str());
-			curl_easy_setopt(curl, CURLOPT_PROXYPORT, settings.m_nProxyPort);
-			if (settings.m_bRequiresAuth) {
-				curl_easy_setopt(curl, CURLOPT_PROXYUSERNAME,std::string(settings.m_strProxyUsername.ToUTF8()).c_str());
-				curl_easy_setopt(curl, CURLOPT_PROXYPASSWORD, std::string(settings.m_strProxyPassword.ToUTF8()).c_str());
+		GNC::GCS::ProxySettings settings = GNC::GCS::ConfigurationController::Instance()->GetProxySettings();
+		if (settings.useProxy) {
+			curl_easy_setopt(curl, CURLOPT_PROXY, settings.hostName.c_str());
+			curl_easy_setopt(curl, CURLOPT_PROXYPORT, settings.port);
+			if (settings.requiresAuth) {
+				curl_easy_setopt(curl, CURLOPT_PROXYUSERNAME, settings.userName.c_str());
+				curl_easy_setopt(curl, CURLOPT_PROXYPASSWORD, settings.password.c_str());
 			}
-			curl_easy_setopt(curl, CURLOPT_NOPROXY, std::string(settings.m_strProxyExceptions.ToUTF8()).c_str());
+			curl_easy_setopt(curl, CURLOPT_NOPROXY, settings.exceptions.c_str());
 		}
 
 		struct curl_httppost* post = NULL;
