@@ -422,9 +422,16 @@ namespace GADAPI {
 			}
 
 			//el pacs sera el primero d la configuracion si no lanzar excepcion
-			std::string pacsStore = m_pIntegracionParams->m_pImportData->m_pIntegrationModel->GlobalVariables.GetValue(GKDI_GLOBAL_PACS_STORE_SID);
-			::GADAPI::SendPACSCommand* pCmd = new ::GADAPI::SendPACSCommand(pacsStore, hl7Message, m_pIntegracionParams->m_InsertedSeries);
-			GNC::Entorno::Instance()->GetCommandController()->ProcessAsync("Processing...",pCmd,NULL);
+			if (GNC::GCS::IControladorPermisos::Instance()->Get("core.integracion", "upload_pacs_xml"))
+			{
+				std::string pacsStore = m_pIntegracionParams->m_pImportData->m_pIntegrationModel->GlobalVariables.GetValue(GKDI_GLOBAL_PACS_STORE_SID);
+				::GADAPI::SendPACSCommand* pCmd = new ::GADAPI::SendPACSCommand(pacsStore, hl7Message, m_pIntegracionParams->m_InsertedSeries);
+				GNC::Entorno::Instance()->GetCommandController()->ProcessAsync("Processing...",pCmd,NULL);
+			}
+			else
+			{
+				LOG_INFO("DicomizeCommand","pacs upload is disabled");
+			}
 		}
 		catch (GIL::HL7::HL7Exception& ex) {
 			std::ostringstream ostr;
