@@ -160,7 +160,7 @@ namespace GADAPI
 		try {
 			pCI = GNC::Entorno::Instance()->GetPACSController();
 			pCI->GetConnection(this);
-			if (GNC::GCS::IControladorPermisos::Instance()->Get("core.integracion", "upload_pacs"))
+			if (GNC::GCS::IControladorPermisos::Instance()->Get("core.pacs.limits", "pacs_upload"))
 			{
 				for (std::map<std::string, std::list<std::string> >::iterator it = mapOfTSyntax.begin(); it != mapOfTSyntax.end(); ++it) {
 					pCI->SubirArchivos(this, m_selectedServer, (*it).second,this,GIL::DICOM::SendDefault);
