@@ -165,7 +165,7 @@ void GNC::CommandLauncher::Park()
 	wxSemaError ret = wxSEMA_TIMEOUT;
 	m_pPool->Return(this);
 	
-	while (!m_Shutdown && ret == wxSEMA_TIMEOUT) {
+	while (!m_Shutdown && !m_Abortar && ret == wxSEMA_TIMEOUT) {
 		ret = m_pParker->WaitTimeout(POLL_PERIOD);		
 	}
 }
@@ -190,7 +190,7 @@ void* GNC::CommandLauncher::Entry()
 		//GNC::GCS::Threading::SetThreadName( GetId(), m_pComando->GetName());
 
 		if (m_pComando != NULL && !m_pComando->EstaAbortado() && m_Dependencias.Size() > 0) {
-			while (m_Dependencias.NotEmpty()) {
+			while (m_Dependencias.NotEmpty()&& !m_pComando->EstaAbortado()) {
 				if (!m_Dependencias.Wait(POLL_PERIOD)) {
 					//std::cout << "Timeout de espera para " << m_pComando->GetName() << "(" << m_idThreadGinkgo << ") " << m_Dependencias.Size() << " pendientes" << std::endl;
 					m_Dependencias.TerminarPendientes();
@@ -222,7 +222,10 @@ void* GNC::CommandLauncher::Entry()
 			catch (...) {
 				LOG_ERROR("CommandLauncher", "Error interno ejecutando el comando con id = " << m_pComando->GetId());
 			}
-
+			
+			OnExit();
+		} else if (m_pComando != NULL && m_pComando->EstaAbortado()) {
+			//aborted commands have to signal to free their dependencies
 			OnExit();
 		}
 
@@ -450,7 +453,7 @@ void GNC::CommandController::ProcessSync(GNC::GCS::IComando* cmd, bool autodelet
 	}
 }
 
-void GNC::CommandController::ProcessAsync(std::string str, GNC::GCS::IComando* cmd, void * owner)
+void GNC::CommandController::ProcessAsync(const std::string& str, GNC::GCS::IComando* cmd, void * owner)
 {
 	cmd->SetOwner(owner);
 	cmd->SetNotificadorProgreso(NULL);
