@@ -117,7 +117,7 @@ namespace GNC {
 
 		~CommandController();
 		virtual void ProcessSync(GNC::GCS::IComando* cmd, bool autodelete, bool update = true, GNC::INotificadorProgreso* pNotifier = NULL);
-		virtual void ProcessAsync(std::string str, GNC::GCS::IComando* cmd, void* owner);
+		virtual void ProcessAsync(const std::string& str, GNC::GCS::IComando* cmd, void* owner);
 		virtual void AbortarComando(GNC::GCS::IComando* pComando, bool sincrono = true);
 		virtual void AbortarComando(long threadId, bool sincrono = true);
 		virtual void AbortarComandosDeOwner(void* owner);
