@@ -83,7 +83,7 @@ GNC::GCS::AnnotationSettings::AnnotationSettings()
 		Modalidad: ${0008|0060}                  // {Modality}
 		*/
 		std::ostringstream ostr;
-		ostr << "${0010|0040:?} ${0010|0030} ${0010,1010}${NEWLINE}${0010|1030:?} Kg ${0010|1020:?} m.${NEWLINE}${0008|1030}${NEWLINE}${0008|0020} ${0008|0030}${NEWLINE}${0008|103E}${NEWLINE}" << _Std("Modality") << ": ${0008|0060}";
+		ostr << "${0010|0040:?} ${0010|0030::date} ${0010,1010}${NEWLINE}${0010|1030:?} Kg ${0010|1020:?} m.${NEWLINE}${0008|1030}${NEWLINE}${0008|0020::date} ${0008|0030::time}${NEWLINE}${0008|103e}${NEWLINE}" << _Std("Modality") << ": ${0008|0060}";
 		annotation[TP_TopRight] = ostr.str();
 	}
 	{
@@ -109,7 +109,7 @@ GNC::GCS::AnnotationSettings::AnnotationSettings()
 		wxString madewith( wxString::Format(_("Made with %s"), appName.c_str()));
 
 		std::ostringstream ostr;
-		ostr << "${0008|0021} ${0008|0031}${NEWLINE}${0070|0081}${NEWLINE}${VIEW.COORDLABELS}${NEWLINE}" << madewith.ToUTF8();
+		ostr << "${0008|0021::date} ${0008|0031::time}${NEWLINE}${0070|0081}${NEWLINE}${VIEW.COORDLABELS}${NEWLINE}" << madewith.ToUTF8();
 		annotation[TP_BottomRight] = ostr.str();
 	}
 }
