@@ -394,7 +394,7 @@ namespace GIL {
 			OFCondition cond;
 
 			typedef GIL::DICOM::DicomDataset TJerarquia;
-
+			//tags
 			for (ListaTags::const_iterator it = base.tags.begin(); it != base.tags.end(); ++it) {
 				DcmElement* e = GIL::DICOM::DICOMManager::CrearElementoConValor((*it).first.c_str());
 
@@ -409,35 +409,36 @@ namespace GIL {
 						LOG_ERROR("PACSCONTROLLER", "No se pudo insertar el elemento: (" << e->getTag().toString().c_str() << "): " << cond.text());
 					}
 				}
+			}
+			//sequences
+			for (TJerarquia::DatasetList::const_iterator it2 = base.secuencias.begin(); it2 != base.secuencias.end(); ++it2) 
+			{
+				const TJerarquia& seq = (*it2);
+				DcmElement* es = GIL::DICOM::DICOMManager::CrearElementoConValor(seq.tagName.c_str());
+				if (es != NULL) {
 
-				for (TJerarquia::DatasetList::const_iterator it2 = base.secuencias.begin(); it2 != base.secuencias.end(); ++it2) {
-					const TJerarquia& seq = (*it2);
-					DcmElement* es = GIL::DICOM::DICOMManager::CrearElementoConValor(seq.tagName.c_str());
-					if (es != NULL) {
+					for (TJerarquia::DatasetList::const_iterator it3 = seq.items.begin(); it3 != seq.items.end(); ++it3) {
+						const TJerarquia& item = (*it3);
+						DcmItem* di = new DcmItem();
 
-						for (TJerarquia::DatasetList::const_iterator it3 = seq.items.begin(); it3 != seq.items.end(); ++it3) {
-							const TJerarquia& item = (*it3);
-							DcmItem* di = new DcmItem();
+						for (ListaTags::const_iterator it4 = item.tags.begin(); it4 != item.tags.end(); ++it4) {
+							DcmElement* ei = GIL::DICOM::DICOMManager::CrearElementoConValor((*it4).first.c_str());
+							if (ei != NULL) {
+								const std::string& val = (*it4).second;
+								if (val.size() > 0) {
+									ei->putString( wxString( (*it4).second.c_str(), wxConvUTF8).mb_str(conv) );
+								}					
+								cond = di->insert(ei, true, false);
 
-							for (ListaTags::const_iterator it4 = item.tags.begin(); it4 != item.tags.end(); ++it4) {
-								DcmElement* ei = GIL::DICOM::DICOMManager::CrearElementoConValor((*it4).first.c_str());
-								if (ei != NULL) {
-									const std::string& val = (*it4).second;
-									if (val.size() > 0) {
-										ei->putString( wxString( (*it4).second.c_str(), wxConvUTF8).mb_str(conv) );
-									}					
-									cond = di->insert(ei, true, false);
-
-									if (cond.bad()) {
-										LOG_ERROR("PACSCONTROLLER", "No se pudo insertar el elemento: (" << ei->getTag().toString().c_str() << "): " << cond.text());
-									}
+								if (cond.bad()) {
+									LOG_ERROR("PACSCONTROLLER", "No se pudo insertar el elemento: (" << ei->getTag().toString().c_str() << "): " << cond.text());
 								}
-
 							}
 
-							query->insertSequenceItem(es->getTag(), di);
-						}					
-					}
+						}
+
+						query->insertSequenceItem(es->getTag(), di);
+					}					
 				}
 			}
 		}
