@@ -51,7 +51,9 @@ namespace GNC {
 
 			virtual ~SmartRetrieveService()
 			{
-				GNC::Entorno::Instance()->GetCommandController()->AbortarComandosDeOwner(this);
+				//can't be synchronous => deathlock
+				GNC::GCS::ControladorEventos::Instance()->DesRegistrar(this);
+				GNC::Entorno::Instance()->GetCommandController()->AbortarComandosDeOwnerAsincrono(this);
 			}
 
 			void Destroy()
