@@ -425,7 +425,7 @@ void GNC::GUI::AcquisitionTableModel::DoExpand(AcquisitionNode* pNode, const std
 	}
 	wxDataViewItemArray arr;
 	pNode->GetChildren(arr);
-	if (arr.empty()) {
+	if (arr.empty() && !pNode->uid.empty()) {
 		GNC::GCS::Ptr<GNC::GCS::StoredQuery> pQuery(new GNC::GCS::StoredQuery());
 		pQuery->setPacsId(server);
 		//insert fields that has to be returned...
@@ -517,7 +517,7 @@ void GNC::GUI::AcquisitionTableModel::ReloadModel(std::list< GNC::GCS::Ptr<GIL::
 		//add a virtual item...
 		GNC::GCS::Ptr<GIL::DICOM::DicomDataset> pDataset(new GIL::DICOM::DicomDataset());
 		pDataset->tags[GKDCM_PatientName] = _Std("No results found");
-		pDataset->tags[GKDCM_StudyInstanceUID] = _Std("0");
+		pDataset->tags[GKDCM_StudyInstanceUID] = "";
 		pDataset->secuencias.push_back(GIL::DICOM::DicomDataset());//dummy
 		AcquisitionNode* pNode = new AcquisitionNode(NULL, pDataset);
 		studyMap[pNode->uid] = pNode;
