@@ -45,11 +45,13 @@ namespace GNC {
 
 			
 		protected:
+			virtual void OnChar(wxKeyEvent &event);
 			virtual void OnLeafClick(wxMouseEvent& event);
 			virtual void OnLeafDClick(wxMouseEvent& event);
 			virtual void OnMouseWheel(wxMouseEvent& event);
 			virtual void OnMenuMouse(wxMouseEvent& event);
 			void OnPaint(wxPaintEvent &event);
+			virtual void OnEraseBackground( wxEraseEvent& event );
 
 			bool                    m_modificado;
 			GNC::GUI::IPreviewLeaf* m_pLeaf;
