@@ -257,7 +257,11 @@ void GNC::GUI::GinkgoToolSystemBar::OnLeftUp(wxMouseEvent& evt)
 	wxAuiToolBarItem* hit_item;
 	hit_item = FindToolByPosition(evt.GetX(), evt.GetY());
 	if (hit_item != NULL && hit_item->IsActive()) {
-		m_pToolBar->ActivateTool(hit_item->GetId(), GNC::GCS::TriggerButton().EnableLeft(), this);
+		GNC::GCS::ITool* pTool = m_pToolBar->GetTool(hit_item->GetId());
+		if (pTool !=NULL && !pTool->AppendsInMenu()) {			
+			//if appends in menu avoid double calling
+			m_pToolBar->ActivateTool(hit_item->GetId(), GNC::GCS::TriggerButton().EnableLeft(), this);
+		}
 	}
 	//don't remove this line, parent has to process the event!!
 	wxGinkgoToolBar::OnLeftUp(evt);
