@@ -88,6 +88,7 @@ GNC::WidgetsManager::WidgetsManager(GNC::GCS::IVista* pVista):GNC::GCS::IWidgets
 	m_cursor = GNC::GCS::Widgets::CUR_FLECHA;
 	m_mouseDerechoDown = false;
 	m_mouseIzquierdoDown = false;
+	m_middleDown = false;
 	m_pTimerAnimation = new TimerAnimation(this);
 
 	GNC::GCS::Widgets::WAnotador* pW = new GNC::GCS::Widgets::WAnotador(this,-1,"",-1);
@@ -209,6 +210,30 @@ void GNC::WidgetsManager::RenderPrivate(GNC::GCS::Contexto3D* c)
 		}
 	} else {
 		bool cursorNotFound = true;
+		if (m_mouseIzquierdoDown) {
+			//si no se lo pedimos al primer builder que encontremos		
+			for (GNC::GCS::ListaBuilders::iterator it = m_pBuilders.begin(); cursorNotFound && it != m_pBuilders.end(); ++it) {
+				if ((*it)->GetButtonMask().IsLeftEnabled()) {
+					if((*it)->GetCursor() != GNC::GCS::Widgets::CUR_INVALIDO){
+						//std::cout << "!WIluminado: !DERDown: Builder cursor " << std::endl;
+						SetCursor((*it)->GetCursor());
+						cursorNotFound = false;
+					}
+				}
+			}
+		}
+		if (m_middleDown)
+		{
+			for (GNC::GCS::ListaBuilders::iterator it = m_pBuilders.begin(); cursorNotFound && it != m_pBuilders.end(); ++it) {
+				if ((*it)->GetButtonMask().IsMiddleEnabled()) {
+					if((*it)->GetCursor() != GNC::GCS::Widgets::CUR_INVALIDO){
+						//std::cout << "!WIluminado: !DERDown: Builder cursor " << std::endl;
+						SetCursor((*it)->GetCursor());
+						cursorNotFound = false;
+					}
+				}
+			}
+		}
 		if (m_mouseDerechoDown) {
 			//builder que atienda al boton derecho
 			for (GNC::GCS::ListaBuilders::iterator it = m_pBuilders.begin(); cursorNotFound && it != m_pBuilders.end(); ++it) {
@@ -221,7 +246,8 @@ void GNC::WidgetsManager::RenderPrivate(GNC::GCS::Contexto3D* c)
 				}
 			}
 		}
-		if (m_mouseIzquierdoDown || cursorNotFound) {
+		if (cursorNotFound) {
+			//try left...
 			//si no se lo pedimos al primer builder que encontremos		
 			for (GNC::GCS::ListaBuilders::iterator it = m_pBuilders.begin(); cursorNotFound && it != m_pBuilders.end(); ++it) {
 				if ((*it)->GetButtonMask().IsLeftEnabled()) {
@@ -232,11 +258,10 @@ void GNC::WidgetsManager::RenderPrivate(GNC::GCS::Contexto3D* c)
 					}
 				}
 			}
-		}
-		if (cursorNotFound) {
-			//y si no pues si esta pulsando el derecho es que esta haciendo pan
-			//std::cout << "!WIluminado: !DERDown: Flecha" << std::endl;
-			SetCursor(GNC::GCS::Widgets::CUR_FLECHA);
+			if (cursorNotFound) 
+			{
+				SetCursor(GNC::GCS::Widgets::CUR_FLECHA);
+			}
 		}
 	}
 
@@ -352,15 +377,11 @@ void GNC::WidgetsManager::OnMouseEvents(GNC::GCS::Events::EventoRaton& evento)
 	}
 
 	//pillamos boton derecho e izquierdo down-up
-	if (evento.ButtonDown(GNC::GCS::Events::EventoRaton::EB_IZQUIERDO)) {
-		m_mouseIzquierdoDown = true;
-	} else if(evento.ButtonUp(GNC::GCS::Events::EventoRaton::EB_IZQUIERDO)){
-		m_mouseIzquierdoDown = false;
-	} else if(evento.ButtonDown(GNC::GCS::Events::EventoRaton::EB_DERECHO)){
-		m_mouseDerechoDown = true;
-	} else if(evento.ButtonUp(GNC::GCS::Events::EventoRaton::EB_DERECHO)){
-		m_mouseDerechoDown = false;
-	}
+	
+	m_mouseIzquierdoDown = evento.LeftIsDown();
+	m_middleDown = evento.MiddleIsDown();
+	m_mouseDerechoDown = evento.RightIsDown();
+	
 
 	// Primera pasada: widgets toplevel.
 	for (IteradorListaWidgets it = m_Widgets.begin(); it != m_Widgets.end(); ++it)
