@@ -46,7 +46,7 @@ GNC::GCS::ITool* GNC::RuleTool::NewTool()
 
 void GNC::RuleTool::Connect()
 {
-	if (RuleContract == NULL) {
+	if (RuleContract == NULL || RuleContract->GetManager()==NULL) {
 		return;
 	}
 	if (m_pRuleBuilder != NULL)
@@ -65,8 +65,14 @@ void GNC::RuleTool::Disconnect()
 	if (RuleContract == NULL) {
 		return;
 	}
-	RuleContract->GetViewerActivo()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
-	RuleContract->GetManager()->SetCursor(GNC::GCS::Widgets::CUR_FLECHA);
+	if (RuleContract->GetViewerActivo() != NULL)
+	{
+		RuleContract->GetViewerActivo()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
+	}
+	if (RuleContract->GetManager() != NULL)
+	{
+		RuleContract->GetManager()->SetCursor(GNC::GCS::Widgets::CUR_FLECHA);
+	}
 	if (m_pRuleBuilder != NULL)
 	{
 		delete m_pRuleBuilder;
