@@ -467,10 +467,17 @@ void GNC::ToolController::OnKeyAccelerator(GNC::GCS::Events::EventoTeclado& even
 
 void GNC::ToolController::ActivateTool(long idTool, const GNC::GCS::TriggerButton& buttonMask, wxWindow* pWindow)
 {
-	//activation will be processed in next iteration of loop event to avoid that component that request activation has been removed in action execution
-	GNC::GUI::wxActivateToolAsync evt(this, idTool, buttonMask, pWindow);
-	evt.SetId(EventHandler->GetId());
-	GNC::GCS::IEntorno::Instance()->GetVentanaRaiz()->GetEventHandler()->AddPendingEvent(evt);
+	if (!wxIsMainThread())
+	{
+		//activation will be processed in next iteration of loop event to avoid that component that request activation has been removed in action execution
+		GNC::GUI::wxActivateToolAsync evt(this, idTool, buttonMask, pWindow);
+		evt.SetId(EventHandler->GetId());
+		GNC::GCS::IEntorno::Instance()->GetVentanaRaiz()->GetEventHandler()->AddPendingEvent(evt);
+	}
+	else
+	{
+		DoActivateTool(idTool, buttonMask, pWindow);
+	}
 }
 
 void GNC::ToolController::DoActivateTool(long idTool, const GNC::GCS::TriggerButton& buttonMask, wxWindow* pWindow)
@@ -533,10 +540,6 @@ void GNC::ToolController::DoActivateTool(long idTool, const GNC::GCS::TriggerBut
 			m_middleTool->GetTriggerButton().EnableMiddle();
 		}
 
-		if(m_leftTool != NULL && m_leftTool->IsEnabled()) {
-			m_leftTool->Connect();
-			GNC::GCS::IEventsController::Instance()->ProcesarEvento(new GNC::GCS::Events::ToolConnectedEvent(true, m_leftTool, this));
-		}
 		if (m_rightTool != NULL && m_rightTool->IsEnabled() && m_rightTool != m_leftTool) {
 			m_rightTool->Connect();
 			GNC::GCS::IEventsController::Instance()->ProcesarEvento(new GNC::GCS::Events::ToolConnectedEvent(true, m_rightTool, this));
@@ -545,6 +548,10 @@ void GNC::ToolController::DoActivateTool(long idTool, const GNC::GCS::TriggerBut
 			m_middleTool->Connect();
 			GNC::GCS::IEventsController::Instance()->ProcesarEvento(new GNC::GCS::Events::ToolConnectedEvent(true, m_middleTool, this));
 		}
+		if(m_leftTool != NULL && m_leftTool->IsEnabled()) {
+			m_leftTool->Connect();
+			GNC::GCS::IEventsController::Instance()->ProcesarEvento(new GNC::GCS::Events::ToolConnectedEvent(true, m_leftTool, this));
+		}
 	}
 }
 
