@@ -11,7 +11,7 @@
 *
 *
 */
-
+#include <algorithm>
 #include <sstream>
 #include <cmath>
 #include <cstring>
@@ -47,7 +47,7 @@
 #include "striptexthelper.h"
 
 namespace GNC {
-	const char* PatientOrientation[10*3*3] = {
+	const char* PatientPositionOrientation[10*3*3] = {
 		"",  "",  "",    "", "",  "",    "", "",  "", // N/A
 		"R", "", "L",   "A", "", "P",   "I", "", "S", // HFS
 		"L", "", "R",   "P", "", "A",   "I", "", "S", // HFP
@@ -58,8 +58,7 @@ namespace GNC {
 		"L", "", "R",   "A", "", "P",   "S", "", "I", // FFS
 		"R", "", "L",   "P", "", "A",   "S", "", "I", // FFP
 		"?", "", "?",   "?", "", "?",   "?", "", "?", // Unknown
-
-	};
+	};	
 }
 
 namespace GNC {
@@ -79,7 +78,7 @@ namespace GNC {
 				} TPosicionAnotacion;
 				OrientationMarks() {
 					m_FontSizeProp = GNC::GCS::IControladorPermisos::Instance()->Get("style", "cornerAnnotation.fontSize").ObtenerValor<float>();
-					m_StripTextRenderer.Update("RLAPIS", GNC::GCS::GLHelper::TColor(ANNOTATOR_TEXT_COLOR), m_FontSizeProp, ANNOTATION_TEXT_WITH_SHADOW);
+					m_StripTextRenderer.Update("RLAPISHF", GNC::GCS::GLHelper::TColor(ANNOTATOR_TEXT_COLOR), m_FontSizeProp, ANNOTATION_TEXT_WITH_SHADOW);
 				}
 
 				~OrientationMarks()
@@ -218,7 +217,7 @@ namespace GNC {
 							return;
 						}
 					}
-					
+
 					const GNC::GCS::Ptr<GNC::GCS::AnnotationSettings>& pAnnotationSettings = pModalitySettings->getAnnotationSettings();
 
 					for (int i = 0; i < GNC::GCS::AnnotationSettings::TP_NumPos; ++i) {
@@ -289,7 +288,7 @@ namespace GNC {
 					//parse annotation...
 					std::ostringstream annotationStream;
 					int initialPos = 0;
-					int defValuePos = 0;
+					int defValuePos,formatPos = 0;
 					std::ostringstream::pos_type lastEndl = 0;
 					std::string tmp;
 					for (int curPos = 0; curPos < str.length(); ++curPos) {
@@ -300,6 +299,7 @@ namespace GNC {
 							if (curPos + 1 < str.length() && str[curPos+1] == '{') {
 								//search for '}'
 								defValuePos = -1;
+								formatPos = -1;
 								bool isTag = false;
 								for (;curPos < str.length(); ++curPos) {
 									if (str[curPos] == '}') {
@@ -307,9 +307,22 @@ namespace GNC {
 										if (pAnnotator.IsValid()) {
 											if (isTag) {
 												if (defValuePos > 0) {
-													annotationStream << pAnnotator->GetTagValue(c, str.substr(initialPos + 2, defValuePos - initialPos - 3), str.substr(defValuePos, curPos - defValuePos));
+													if (formatPos > 0)
+													{
+														std::string lowerTag = str.substr(initialPos + 2, defValuePos - initialPos - 3);
+														std::transform(lowerTag.begin(), lowerTag.end(), lowerTag.begin(), ::tolower);
+														annotationStream << pAnnotator->GetTagValue(c, lowerTag, str.substr(defValuePos, formatPos - defValuePos), str.substr(formatPos, curPos - formatPos));
+													}
+													else
+													{
+														std::string lowerTag = str.substr(initialPos + 2, defValuePos - initialPos - 3);
+														std::transform(lowerTag.begin(), lowerTag.end(), lowerTag.begin(), ::tolower);
+														annotationStream << pAnnotator->GetTagValue(c, lowerTag, str.substr(defValuePos, curPos - defValuePos));
+													}
 												} else {
-													annotationStream << pAnnotator->GetTagValue(c, str.substr(initialPos + 2, curPos - initialPos -2));
+													std::string lowerTag = str.substr(initialPos + 2, curPos - initialPos -2);
+													std::transform(lowerTag.begin(), lowerTag.end(), lowerTag.begin(), ::tolower);
+													annotationStream << pAnnotator->GetTagValue(c, lowerTag);
 												}
 											} else {
 												tmp = pAnnotator->GetAnnotationValue(c, str.substr(initialPos, curPos - initialPos + 1));
@@ -329,7 +342,15 @@ namespace GNC {
 										}
 										break;
 									} else if (str[curPos] == ':') {
-										defValuePos = curPos + 1;
+										//this could be defvalue or format
+										if (defValuePos > 0)
+										{
+											formatPos = curPos + 1;
+										} 
+										else
+										{
+											defValuePos = curPos + 1;
+										}
 									} else if (str[curPos] == '|') {
 										isTag = true;
 									}
@@ -538,7 +559,7 @@ namespace GNC {
 						}
 					}
 				}
-				
+
 			};
 
 			/**
@@ -546,7 +567,7 @@ namespace GNC {
 			* strPos: The patient position string (HFS, HFP...)
 			* defautlunknown: When orientation index is empty, set the default index to unknown ("?") or empty ("") values
 			**/
-			int GetOrientationIndex(const std::string& strPos, bool defaultunknown) {
+			int GetPatientPositionOrientationIndex(const std::string& strPos, bool defaultunknown) {
 
 				if (strcmp(strPos.c_str(), "HFS") == 0) {
 					return 1;
@@ -582,16 +603,16 @@ namespace GNC {
 
 			/**
 			* Gets the patient orientation char ("R", "L", "S"...) from:
-			* patientPosIndex: The patient position index: get if from GetOrientationIndex() call.
+			* patientPosIndex: The patient position index: get if from GetPatientPositionOrientationIndex() call.
 			* axis: The axis: 0==x, 1==y, 2==z
 			* dir: The direction: -1 == decreasing, +1 == decreasing
 			**/
-			const char* GetOrientationChar(int patientPosIndex, int axis, int dir) {
+			const char* GetPatientPositionOrientationChar(int patientPosIndex, int axis, int dir) {
 				const int offPos = 9 * patientPosIndex;
 				const int offAxis = 3 * axis;
 				const int offDir = 1 + dir;
 
-				return PatientOrientation[offPos + offAxis + offDir];
+				return PatientPositionOrientation[offPos + offAxis + offDir];
 			}
 		}
 	}
@@ -672,17 +693,17 @@ void GNC::GCS::Widgets::WAnotador::Render(GNC::GCS::Contexto3D* c)
 
 
 	pAnotaciones->Redimensionar(viewport);
-	
+
 	pAnotaciones->Recalculate(c, m_pManager->GetAnnotator());
 
 	RecalcularPosicion(pOrientation, c);
 
-	
+
 	pAnotaciones->Actualizar(m_color);
 
 	pAnotaciones->Render(c);
 	pOrientation->Render(c, pAnotaciones->m_RectViewport);
-	
+
 
 	glPopMatrix();
 
@@ -727,7 +748,7 @@ void GNC::GCS::Widgets::WAnotador::RecalcularPosicion(OrientationMarks* pAnotaci
 	pAnotaciones->SetAnotation(OrientationMarks::TP_Right, dirs[1].str());
 	pAnotaciones->SetAnotation(OrientationMarks::TP_Top, dirs[2].str());	
 	pAnotaciones->SetAnotation(OrientationMarks::TP_Bottom, dirs[3].str());
-	
+
 }
 
 void GNC::GCS::Widgets::WAnotador::ComputeOrientation(GNC::GCS::Contexto3D* c, std::ostringstream* dirs )
@@ -771,209 +792,489 @@ void GNC::GCS::Widgets::WAnotador::ComputeOrientation(GNC::GCS::Contexto3D* c, s
 	if (m_pManager->GetAnnotator().IsValid()) {
 		patPosition = m_pManager->GetAnnotator()->GetTagValue(c, GKDCM_PatientPosition);
 	}
+	if (patPosition.empty()) {
+		
+		std::string viewPosition = m_pManager->GetAnnotator()->GetTagValue(c, GKDCM_ViewPosition);
+		std::string patientOrientation = m_pManager->GetAnnotator()->GetTagValue(c, GKDCM_PatientOrientation);
 
-	int patientPosIndex = GetOrientationIndex(patPosition, false);
+		LOG_DEBUG("View", "Computing orientation from [ ViewPosition = " << viewPosition << ", PatientOrientation = " << patientOrientation << " ]");
+
+		if (!viewPosition.empty() && !patientOrientation.empty()) {			
+
+			if (viewPosition.find("CC") != std::string::npos) {
+				LOG_DEBUG("View", "Warning: CC ViewPosition not supported yet");
+				return;
+			}
+
+			std::string DynamicPatientPositionOrientation[] = {
+				"",  "",  "",    "", "", "",   "", "", "",
+			};
+			char direction[2] = {'?', '?'}; // Annotations for each axis direction (columns, rows)
+
+			std::istringstream pis(patientOrientation);
+
+			if (pis.eof()) { // Read first char (pixel columns orientation)
+				return;
+			}
+			direction[0] = (char) pis.get();
+			if (pis.eof()) {
+				return;
+			}
+			pis.get(); // Read separator
+			if (pis.eof()) {
+				return;
+			}
+			direction[1] = (char) pis.get(); // Read first char (pixel rows orientation)
+
+			for (int i = 0; i < 2; ++i) { // Compute directions dinamically
+				int curPos = 1 + i*3;
+
+				switch (direction[i]) {
+				case 'A':
+					DynamicPatientPositionOrientation[curPos - 1] = "P";
+					DynamicPatientPositionOrientation[curPos + 1] = "A";
+					break;
+				case 'P':
+					DynamicPatientPositionOrientation[curPos - 1] = "A";
+					DynamicPatientPositionOrientation[curPos + 1] = "P";
+					break;
+				case 'R':
+					DynamicPatientPositionOrientation[curPos - 1] = "L";
+					DynamicPatientPositionOrientation[curPos + 1] = "R";
+					break;
+				case 'L':
+					DynamicPatientPositionOrientation[curPos - 1] = "R";
+					DynamicPatientPositionOrientation[curPos + 1] = "L";
+					break;
+				case 'H':
+					DynamicPatientPositionOrientation[curPos - 1] = "F";
+					DynamicPatientPositionOrientation[curPos + 1] = "H";
+					break;
+				case 'F':
+					DynamicPatientPositionOrientation[curPos - 1] = "H";
+					DynamicPatientPositionOrientation[curPos + 1] = "F";
+					break;
+				default:
+					break;
+				}
+			}
+
+			if (viewPosition == "AP") {
+				DynamicPatientPositionOrientation[6] = "A";
+				DynamicPatientPositionOrientation[8] = "P";
+			}
+			else if (viewPosition == "PA") {
+				DynamicPatientPositionOrientation[6] = "P";
+				DynamicPatientPositionOrientation[8] = "A";
+			}
 
 
+			const int offPos = 0;
+			const int offX = 0;
+			const int offY = 3;
+			const int offZ = 6;
+			const int offSignNeg = 0;
+			const int offSignZero = 1;
+			const int offSignPos = 2;
 
-	LOG_DEBUG("View", "Current orientation:");
-	LOG_DEBUG("View", "Left = " << camOrient[0][1] << ", Right = " << camOrient[0][0]);
-	LOG_DEBUG("View", "Up  = " << camOrient[1][0] << ", Down = " << camOrient[1][1]);
-	LOG_DEBUG("View", "Back  = " << camOrient[2][0] << ", Front = " << camOrient[2][1]);
+			// Left X:
+			if (camOrient[0][1][0] == 1.0) {
+				dirs[0] << DynamicPatientPositionOrientation[offPos + offX + offSignPos];
+			}
+			else if (camOrient[0][1][0] == -1.0) {
+				dirs[0] << DynamicPatientPositionOrientation[offPos + offX + offSignNeg];
+			}
+			else {
+				dirs[0] << DynamicPatientPositionOrientation[offPos + offX + offSignZero];
+			}
+			// Left Y:
+			if (camOrient[0][1][1] == 1.0) {
+				dirs[0] << DynamicPatientPositionOrientation[offPos + offY + offSignPos];
+			}
+			else if (camOrient[0][1][1] == -1.0) {
+				dirs[0] << DynamicPatientPositionOrientation[offPos + offY + offSignNeg];
+			}
+			else {
+				dirs[0] << DynamicPatientPositionOrientation[offPos + offY + offSignZero];
+			}
+			// Left Z:
+			if (camOrient[0][1][2] == 1.0) {
+				dirs[0] << DynamicPatientPositionOrientation[offPos + offZ + offSignPos];
+			}
+			else if (camOrient[0][1][2] == -1.0) {
+				dirs[0] << DynamicPatientPositionOrientation[offPos + offZ + offSignNeg];
+			}
+			else {
+				dirs[0] << DynamicPatientPositionOrientation[offPos + offZ + offSignZero];
+			}
 
-	const int offPos = 9 * patientPosIndex;
-	const int offX = 0;
-	const int offY = 3;
-	const int offZ = 6;
-	const int offSignNeg = 0;
-	const int offSignZero = 1;
-	const int offSignPos = 2;
+			// Right X:
+			if (camOrient[0][0][0] == 1.0) {
+				dirs[1] << DynamicPatientPositionOrientation[offPos + offX + offSignPos];
+			}
+			else if (camOrient[0][0][0] == -1.0) {
+				dirs[1] << DynamicPatientPositionOrientation[offPos + offX + offSignNeg];
+			}
+			else {
+				dirs[1] << DynamicPatientPositionOrientation[offPos + offX + offSignZero];
+			}
+			// Right Y:
+			if (camOrient[0][0][1] == 1.0) {
+				dirs[1] << DynamicPatientPositionOrientation[offPos + offY + offSignPos];
+			}
+			else if (camOrient[0][0][1] == -1.0) {
+				dirs[1] << DynamicPatientPositionOrientation[offPos + offY + offSignNeg];
+			}
+			else {
+				dirs[1] << DynamicPatientPositionOrientation[offPos + offY + offSignZero];
+			}
+			// Right Z:
+			if (camOrient[0][0][2] == 1.0) {
+				dirs[1] << DynamicPatientPositionOrientation[offPos + offZ + offSignPos];
+			}
+			else if (camOrient[0][0][2] == -1.0) {
+				dirs[1] << DynamicPatientPositionOrientation[offPos + offZ + offSignNeg];
+			}
+			else {
+				dirs[1] << DynamicPatientPositionOrientation[offPos + offZ + offSignZero];
+			}
 
-	// Left X:
-	if (camOrient[0][1][0] == 1.0) {
-		dirs[0] << PatientOrientation[offPos + offX + offSignPos];
-	}
-	else if (camOrient[0][1][0] == -1.0) {
-		dirs[0] << PatientOrientation[offPos + offX + offSignNeg];
-	}
-	else {
-		dirs[0] << PatientOrientation[offPos + offX + offSignZero];
-	}
-	// Left Y:
-	if (camOrient[0][1][1] == 1.0) {
-		dirs[0] << PatientOrientation[offPos + offY + offSignPos];
-	}
-	else if (camOrient[0][1][1] == -1.0) {
-		dirs[0] << PatientOrientation[offPos + offY + offSignNeg];
-	}
-	else {
-		dirs[0] << PatientOrientation[offPos + offY + offSignZero];
-	}
-	// Left Z:
-	if (camOrient[0][1][2] == 1.0) {
-		dirs[0] << PatientOrientation[offPos + offZ + offSignPos];
-	}
-	else if (camOrient[0][1][2] == -1.0) {
-		dirs[0] << PatientOrientation[offPos + offZ + offSignNeg];
-	}
-	else {
-		dirs[0] << PatientOrientation[offPos + offZ + offSignZero];
-	}
+			// Top X:
+			if (camOrient[1][0][0] == 1.0) {
+				dirs[2] << DynamicPatientPositionOrientation[offPos + offX + offSignPos];
+			}
+			else if (camOrient[1][0][0] == -1.0) {
+				dirs[2] << DynamicPatientPositionOrientation[offPos + offX + offSignNeg];
+			}
+			else {
+				dirs[2] << DynamicPatientPositionOrientation[offPos + offX + offSignZero];
+			}
+			// Top Y:
+			if (camOrient[1][0][1] == 1.0) {
+				dirs[2] << DynamicPatientPositionOrientation[offPos + offY + offSignPos];
+			}
+			else if (camOrient[1][0][1] == -1.0) {
+				dirs[2] << DynamicPatientPositionOrientation[offPos + offY + offSignNeg];
+			}
+			else {
+				dirs[2] << DynamicPatientPositionOrientation[offPos + offY + offSignZero];
+			}
+			// Top Z:
+			if (camOrient[1][0][2] == 1.0) {
+				dirs[2] << DynamicPatientPositionOrientation[offPos + offZ + offSignPos];
+			}
+			else if (camOrient[1][0][2] == -1.0) {
+				dirs[2] << DynamicPatientPositionOrientation[offPos + offZ + offSignNeg];
+			}
+			else {
+				dirs[2] << DynamicPatientPositionOrientation[offPos + offZ + offSignZero];
+			}
 
-	// Right X:
-	if (camOrient[0][0][0] == 1.0) {
-		dirs[1] << PatientOrientation[offPos + offX + offSignPos];
-	}
-	else if (camOrient[0][0][0] == -1.0) {
-		dirs[1] << PatientOrientation[offPos + offX + offSignNeg];
-	}
-	else {
-		dirs[1] << PatientOrientation[offPos + offX + offSignZero];
-	}
-	// Right Y:
-	if (camOrient[0][0][1] == 1.0) {
-		dirs[1] << PatientOrientation[offPos + offY + offSignPos];
-	}
-	else if (camOrient[0][0][1] == -1.0) {
-		dirs[1] << PatientOrientation[offPos + offY + offSignNeg];
-	}
-	else {
-		dirs[1] << PatientOrientation[offPos + offY + offSignZero];
-	}
-	// Right Z:
-	if (camOrient[0][0][2] == 1.0) {
-		dirs[1] << PatientOrientation[offPos + offZ + offSignPos];
-	}
-	else if (camOrient[0][0][2] == -1.0) {
-		dirs[1] << PatientOrientation[offPos + offZ + offSignNeg];
-	}
-	else {
-		dirs[1] << PatientOrientation[offPos + offZ + offSignZero];
-	}
+			// Bottom X:
+			if (camOrient[1][1][0] == 1.0) {
+				dirs[3] << DynamicPatientPositionOrientation[offPos + offX + offSignPos];
+			}
+			else if (camOrient[1][1][0] == -1.0) {
+				dirs[3] << DynamicPatientPositionOrientation[offPos + offX + offSignNeg];
+			}
+			else {
+				dirs[3] << DynamicPatientPositionOrientation[offPos + offX + offSignZero];
+			}
+			// Bottom Y:
+			if (camOrient[1][1][1] == 1.0) {
+				dirs[3] << DynamicPatientPositionOrientation[offPos + offY + offSignPos];
+			}
+			else if (camOrient[1][1][1] == -1.0) {
+				dirs[3] << DynamicPatientPositionOrientation[offPos + offY + offSignNeg];
+			}
+			else {
+				dirs[3] << DynamicPatientPositionOrientation[offPos + offY + offSignZero];
+			}
+			// Bottom Z:
+			if (camOrient[1][1][2] == 1.0) {
+				dirs[3] << DynamicPatientPositionOrientation[offPos + offZ + offSignPos];
+			}
+			else if (camOrient[1][1][2] == -1.0) {
+				dirs[3] << DynamicPatientPositionOrientation[offPos + offZ + offSignNeg];
+			}
+			else {
+				dirs[3] << DynamicPatientPositionOrientation[offPos + offZ + offSignZero];
+			}
 
-	// Top X:
-	if (camOrient[1][0][0] == 1.0) {
-		dirs[2] << PatientOrientation[offPos + offX + offSignPos];
-	}
-	else if (camOrient[1][0][0] == -1.0) {
-		dirs[2] << PatientOrientation[offPos + offX + offSignNeg];
-	}
-	else {
-		dirs[2] << PatientOrientation[offPos + offX + offSignZero];
-	}
-	// Top Y:
-	if (camOrient[1][0][1] == 1.0) {
-		dirs[2] << PatientOrientation[offPos + offY + offSignPos];
-	}
-	else if (camOrient[1][0][1] == -1.0) {
-		dirs[2] << PatientOrientation[offPos + offY + offSignNeg];
-	}
-	else {
-		dirs[2] << PatientOrientation[offPos + offY + offSignZero];
-	}
-	// Top Z:
-	if (camOrient[1][0][2] == 1.0) {
-		dirs[2] << PatientOrientation[offPos + offZ + offSignPos];
-	}
-	else if (camOrient[1][0][2] == -1.0) {
-		dirs[2] << PatientOrientation[offPos + offZ + offSignNeg];
-	}
-	else {
-		dirs[2] << PatientOrientation[offPos + offZ + offSignZero];
-	}
+			// Extended
+			// Back X:
+			if (camOrient[2][1][0] == 1.0) {
+				dirs[4] << DynamicPatientPositionOrientation[offPos + offX + offSignPos];
+			}
+			else if (camOrient[2][1][0] == -1.0) {
+				dirs[4] << DynamicPatientPositionOrientation[offPos + offX + offSignNeg];
+			}
+			else {
+				dirs[4] << DynamicPatientPositionOrientation[offPos + offX + offSignZero];
+			}
+			// Back Y:
+			if (camOrient[2][1][1] == 1.0) {
+				dirs[4] << DynamicPatientPositionOrientation[offPos + offY + offSignPos];
+			}
+			else if (camOrient[2][1][1] == -1.0) {
+				dirs[4] << DynamicPatientPositionOrientation[offPos + offY + offSignNeg];
+			}
+			else {
+				dirs[4] << DynamicPatientPositionOrientation[offPos + offY + offSignZero];
+			}
+			// Back Z:
+			if (camOrient[2][1][2] == 1.0) {
+				dirs[4] << DynamicPatientPositionOrientation[offPos + offZ + offSignPos];
+			}
+			else if (camOrient[2][1][2] == -1.0) {
+				dirs[4] << DynamicPatientPositionOrientation[offPos + offZ + offSignNeg];
+			}
+			else {
+				dirs[4] << DynamicPatientPositionOrientation[offPos + offZ + offSignZero];
+			}
 
-	// Bottom X:
-	if (camOrient[1][1][0] == 1.0) {
-		dirs[3] << PatientOrientation[offPos + offX + offSignPos];
-	}
-	else if (camOrient[1][1][0] == -1.0) {
-		dirs[3] << PatientOrientation[offPos + offX + offSignNeg];
-	}
-	else {
-		dirs[3] << PatientOrientation[offPos + offX + offSignZero];
-	}
-	// Bottom Y:
-	if (camOrient[1][1][1] == 1.0) {
-		dirs[3] << PatientOrientation[offPos + offY + offSignPos];
-	}
-	else if (camOrient[1][1][1] == -1.0) {
-		dirs[3] << PatientOrientation[offPos + offY + offSignNeg];
-	}
-	else {
-		dirs[3] << PatientOrientation[offPos + offY + offSignZero];
-	}
-	// Bottom Z:
-	if (camOrient[1][1][2] == 1.0) {
-		dirs[3] << PatientOrientation[offPos + offZ + offSignPos];
-	}
-	else if (camOrient[1][1][2] == -1.0) {
-		dirs[3] << PatientOrientation[offPos + offZ + offSignNeg];
-	}
-	else {
-		dirs[3] << PatientOrientation[offPos + offZ + offSignZero];
-	}
+			// Front X:
+			if (camOrient[2][0][0] == 1.0) {
+				dirs[5] << DynamicPatientPositionOrientation[offPos + offX + offSignPos];
+			}
+			else if (camOrient[2][0][0] == -1.0) {
+				dirs[5] << DynamicPatientPositionOrientation[offPos + offX + offSignNeg];
+			}
+			else {
+				dirs[5] << DynamicPatientPositionOrientation[offPos + offX + offSignZero];
+			}
+			// Front Y:
+			if (camOrient[2][0][1] == 1.0) {
+				dirs[5] << DynamicPatientPositionOrientation[offPos + offY + offSignPos];
+			}
+			else if (camOrient[2][0][1] == -1.0) {
+				dirs[5] << DynamicPatientPositionOrientation[offPos + offY + offSignNeg];
+			}
+			else {
+				dirs[5] << DynamicPatientPositionOrientation[offPos + offY + offSignZero];
+			}
+			// Front Z:
+			if (camOrient[2][0][2] == 1.0) {
+				dirs[5] << DynamicPatientPositionOrientation[offPos + offZ + offSignPos];
+			}
+			else if (camOrient[2][0][2] == -1.0) {
+				dirs[5] << DynamicPatientPositionOrientation[offPos + offZ + offSignNeg];
+			}
+			else {
+				dirs[5] << DynamicPatientPositionOrientation[offPos + offZ + offSignZero];
+			}
 
-	// Extended
-	// Back X:
-	if (camOrient[2][1][0] == 1.0) {
-		dirs[4] << PatientOrientation[offPos + offX + offSignPos];
-	}
-	else if (camOrient[2][1][0] == -1.0) {
-		dirs[4] << PatientOrientation[offPos + offX + offSignNeg];
-	}
-	else {
-		dirs[4] << PatientOrientation[offPos + offX + offSignZero];
-	}
-	// Back Y:
-	if (camOrient[2][1][1] == 1.0) {
-		dirs[4] << PatientOrientation[offPos + offY + offSignPos];
-	}
-	else if (camOrient[2][1][1] == -1.0) {
-		dirs[4] << PatientOrientation[offPos + offY + offSignNeg];
-	}
-	else {
-		dirs[4] << PatientOrientation[offPos + offY + offSignZero];
-	}
-	// Back Z:
-	if (camOrient[2][1][2] == 1.0) {
-		dirs[4] << PatientOrientation[offPos + offZ + offSignPos];
-	}
-	else if (camOrient[2][1][2] == -1.0) {
-		dirs[4] << PatientOrientation[offPos + offZ + offSignNeg];
-	}
-	else {
-		dirs[4] << PatientOrientation[offPos + offZ + offSignZero];
-	}
+			LOG_DEBUG("View", "Annotation:");
+			LOG_DEBUG("View", "    " << dirs[2].str() << "   ");
+			LOG_DEBUG("View", "  " << dirs[0].str() << "   " << dirs[1].str() << " ");
+			LOG_DEBUG("View", "    " << dirs[3].str() << "   ");
 
-	// Front X:
-	if (camOrient[2][0][0] == 1.0) {
-		dirs[5] << PatientOrientation[offPos + offX + offSignPos];
-	}
-	else if (camOrient[2][0][0] == -1.0) {
-		dirs[5] << PatientOrientation[offPos + offX + offSignNeg];
+		}
 	}
 	else {
-		dirs[5] << PatientOrientation[offPos + offX + offSignZero];
-	}
-	// Front Y:
-	if (camOrient[2][0][1] == 1.0) {
-		dirs[5] << PatientOrientation[offPos + offY + offSignPos];
-	}
-	else if (camOrient[2][0][1] == -1.0) {
-		dirs[5] << PatientOrientation[offPos + offY + offSignNeg];
-	}
-	else {
-		dirs[5] << PatientOrientation[offPos + offY + offSignZero];
-	}
-	// Front Z:
-	if (camOrient[2][0][2] == 1.0) {
-		dirs[5] << PatientOrientation[offPos + offZ + offSignPos];
-	}
-	else if (camOrient[2][0][2] == -1.0) {
-		dirs[5] << PatientOrientation[offPos + offZ + offSignNeg];
-	}
-	else {
-		dirs[5] << PatientOrientation[offPos + offZ + offSignZero];
+		LOG_DEBUG("View", "Computing orientation from [ PatientPosition = " << patPosition << " ]");
+		int patientPosIndex = GetPatientPositionOrientationIndex(patPosition, false);
+
+
+		LOG_DEBUG("View", "Current orientation:");
+		LOG_DEBUG("View", "Left = " << camOrient[0][1] << ", Right = " << camOrient[0][0]);
+		LOG_DEBUG("View", "Up  = " << camOrient[1][0] << ", Down = " << camOrient[1][1]);
+		LOG_DEBUG("View", "Back  = " << camOrient[2][0] << ", Front = " << camOrient[2][1]);
+
+		const int offPos = 9 * patientPosIndex;
+		const int offX = 0;
+		const int offY = 3;
+		const int offZ = 6;
+		const int offSignNeg = 0;
+		const int offSignZero = 1;
+		const int offSignPos = 2;
+
+		// Left X:
+		if (camOrient[0][1][0] == 1.0) {
+			dirs[0] << PatientPositionOrientation[offPos + offX + offSignPos];
+		}
+		else if (camOrient[0][1][0] == -1.0) {
+			dirs[0] << PatientPositionOrientation[offPos + offX + offSignNeg];
+		}
+		else {
+			dirs[0] << PatientPositionOrientation[offPos + offX + offSignZero];
+		}
+		// Left Y:
+		if (camOrient[0][1][1] == 1.0) {
+			dirs[0] << PatientPositionOrientation[offPos + offY + offSignPos];
+		}
+		else if (camOrient[0][1][1] == -1.0) {
+			dirs[0] << PatientPositionOrientation[offPos + offY + offSignNeg];
+		}
+		else {
+			dirs[0] << PatientPositionOrientation[offPos + offY + offSignZero];
+		}
+		// Left Z:
+		if (camOrient[0][1][2] == 1.0) {
+			dirs[0] << PatientPositionOrientation[offPos + offZ + offSignPos];
+		}
+		else if (camOrient[0][1][2] == -1.0) {
+			dirs[0] << PatientPositionOrientation[offPos + offZ + offSignNeg];
+		}
+		else {
+			dirs[0] << PatientPositionOrientation[offPos + offZ + offSignZero];
+		}
+
+		// Right X:
+		if (camOrient[0][0][0] == 1.0) {
+			dirs[1] << PatientPositionOrientation[offPos + offX + offSignPos];
+		}
+		else if (camOrient[0][0][0] == -1.0) {
+			dirs[1] << PatientPositionOrientation[offPos + offX + offSignNeg];
+		}
+		else {
+			dirs[1] << PatientPositionOrientation[offPos + offX + offSignZero];
+		}
+		// Right Y:
+		if (camOrient[0][0][1] == 1.0) {
+			dirs[1] << PatientPositionOrientation[offPos + offY + offSignPos];
+		}
+		else if (camOrient[0][0][1] == -1.0) {
+			dirs[1] << PatientPositionOrientation[offPos + offY + offSignNeg];
+		}
+		else {
+			dirs[1] << PatientPositionOrientation[offPos + offY + offSignZero];
+		}
+		// Right Z:
+		if (camOrient[0][0][2] == 1.0) {
+			dirs[1] << PatientPositionOrientation[offPos + offZ + offSignPos];
+		}
+		else if (camOrient[0][0][2] == -1.0) {
+			dirs[1] << PatientPositionOrientation[offPos + offZ + offSignNeg];
+		}
+		else {
+			dirs[1] << PatientPositionOrientation[offPos + offZ + offSignZero];
+		}
+
+		// Top X:
+		if (camOrient[1][0][0] == 1.0) {
+			dirs[2] << PatientPositionOrientation[offPos + offX + offSignPos];
+		}
+		else if (camOrient[1][0][0] == -1.0) {
+			dirs[2] << PatientPositionOrientation[offPos + offX + offSignNeg];
+		}
+		else {
+			dirs[2] << PatientPositionOrientation[offPos + offX + offSignZero];
+		}
+		// Top Y:
+		if (camOrient[1][0][1] == 1.0) {
+			dirs[2] << PatientPositionOrientation[offPos + offY + offSignPos];
+		}
+		else if (camOrient[1][0][1] == -1.0) {
+			dirs[2] << PatientPositionOrientation[offPos + offY + offSignNeg];
+		}
+		else {
+			dirs[2] << PatientPositionOrientation[offPos + offY + offSignZero];
+		}
+		// Top Z:
+		if (camOrient[1][0][2] == 1.0) {
+			dirs[2] << PatientPositionOrientation[offPos + offZ + offSignPos];
+		}
+		else if (camOrient[1][0][2] == -1.0) {
+			dirs[2] << PatientPositionOrientation[offPos + offZ + offSignNeg];
+		}
+		else {
+			dirs[2] << PatientPositionOrientation[offPos + offZ + offSignZero];
+		}
+
+		// Bottom X:
+		if (camOrient[1][1][0] == 1.0) {
+			dirs[3] << PatientPositionOrientation[offPos + offX + offSignPos];
+		}
+		else if (camOrient[1][1][0] == -1.0) {
+			dirs[3] << PatientPositionOrientation[offPos + offX + offSignNeg];
+		}
+		else {
+			dirs[3] << PatientPositionOrientation[offPos + offX + offSignZero];
+		}
+		// Bottom Y:
+		if (camOrient[1][1][1] == 1.0) {
+			dirs[3] << PatientPositionOrientation[offPos + offY + offSignPos];
+		}
+		else if (camOrient[1][1][1] == -1.0) {
+			dirs[3] << PatientPositionOrientation[offPos + offY + offSignNeg];
+		}
+		else {
+			dirs[3] << PatientPositionOrientation[offPos + offY + offSignZero];
+		}
+		// Bottom Z:
+		if (camOrient[1][1][2] == 1.0) {
+			dirs[3] << PatientPositionOrientation[offPos + offZ + offSignPos];
+		}
+		else if (camOrient[1][1][2] == -1.0) {
+			dirs[3] << PatientPositionOrientation[offPos + offZ + offSignNeg];
+		}
+		else {
+			dirs[3] << PatientPositionOrientation[offPos + offZ + offSignZero];
+		}
+
+		// Extended
+		// Back X:
+		if (camOrient[2][1][0] == 1.0) {
+			dirs[4] << PatientPositionOrientation[offPos + offX + offSignPos];
+		}
+		else if (camOrient[2][1][0] == -1.0) {
+			dirs[4] << PatientPositionOrientation[offPos + offX + offSignNeg];
+		}
+		else {
+			dirs[4] << PatientPositionOrientation[offPos + offX + offSignZero];
+		}
+		// Back Y:
+		if (camOrient[2][1][1] == 1.0) {
+			dirs[4] << PatientPositionOrientation[offPos + offY + offSignPos];
+		}
+		else if (camOrient[2][1][1] == -1.0) {
+			dirs[4] << PatientPositionOrientation[offPos + offY + offSignNeg];
+		}
+		else {
+			dirs[4] << PatientPositionOrientation[offPos + offY + offSignZero];
+		}
+		// Back Z:
+		if (camOrient[2][1][2] == 1.0) {
+			dirs[4] << PatientPositionOrientation[offPos + offZ + offSignPos];
+		}
+		else if (camOrient[2][1][2] == -1.0) {
+			dirs[4] << PatientPositionOrientation[offPos + offZ + offSignNeg];
+		}
+		else {
+			dirs[4] << PatientPositionOrientation[offPos + offZ + offSignZero];
+		}
+
+		// Front X:
+		if (camOrient[2][0][0] == 1.0) {
+			dirs[5] << PatientPositionOrientation[offPos + offX + offSignPos];
+		}
+		else if (camOrient[2][0][0] == -1.0) {
+			dirs[5] << PatientPositionOrientation[offPos + offX + offSignNeg];
+		}
+		else {
+			dirs[5] << PatientPositionOrientation[offPos + offX + offSignZero];
+		}
+		// Front Y:
+		if (camOrient[2][0][1] == 1.0) {
+			dirs[5] << PatientPositionOrientation[offPos + offY + offSignPos];
+		}
+		else if (camOrient[2][0][1] == -1.0) {
+			dirs[5] << PatientPositionOrientation[offPos + offY + offSignNeg];
+		}
+		else {
+			dirs[5] << PatientPositionOrientation[offPos + offY + offSignZero];
+		}
+		// Front Z:
+		if (camOrient[2][0][2] == 1.0) {
+			dirs[5] << PatientPositionOrientation[offPos + offZ + offSignPos];
+		}
+		else if (camOrient[2][0][2] == -1.0) {
+			dirs[5] << PatientPositionOrientation[offPos + offZ + offSignNeg];
+		}
+		else {
+			dirs[5] << PatientPositionOrientation[offPos + offZ + offSignZero];
+		}
 	}
 
 }
@@ -998,7 +1299,7 @@ void GNC::GCS::Widgets::WAnotador::OffscreenRender(GNC::GCS::Contexto3D* c)
 	GNC::GCS::Vector TamViewPort = ((RectViewport[1] - RectViewport[0]).ValorAbsoluto() * PROPVIEWPORT).Redondear();
 
 	GNC::GCS::Vector TamCajaMaxima = (RectViewport[1] - RectViewport[0]).ValorAbsoluto();
-	
+
 	const std::string        TextoAnotacion[WAnotador::TP_NumPosiciones] = {"","","",""};/////////////{ m_pAnnotator->GetTopLeftAnnotation(c), m_pAnnotator->GetTopRightAnnotation(c), m_pAnnotator->GetBottomLeftAnnotation(c), m_pAnnotator->GetBottomRightAnnotation(c) };
 	GNC::GCS::Vector         TamTexto      [WAnotador::TP_NumPosiciones];
 	GNC::GCS::Widgets::HelperTexto::TAlineamiento Alineacion[4] = { GNC::GCS::Widgets::HelperTexto::TA_Izquierda, GNC::GCS::Widgets::HelperTexto::TA_Derecha, GNC::GCS::Widgets::HelperTexto::TA_Izquierda, GNC::GCS::Widgets::HelperTexto::TA_Derecha };
