@@ -17,7 +17,9 @@
 #include <api/icontexto.h>
 #include <api/iwidgetsrenderer.h>
 #include "welipse.h"
+#include "wtextbox.h"
 #include <api/ievento.h>
+#include <api/ioverlay.h>
 #include "main/managers/widgetsmanager.h"
 #include <vtkgl.h>
 #include <api/westilo.h>
@@ -79,7 +81,7 @@ void GNC::GCS::Widgets::WElipseBuilder::OnMouseEvents(GNC::GCS::Events::EventoRa
 			TVector radio2(0.0f, bBox[1].y - centro.y);
 			*/
 
-			WElipse* w = new WElipse(centro, m_RadioMayor/2, m_RadioMenor/2, m_pManager, evento.c->GetRenderer()->GetVID(), "Elipse", m_GID);
+			WElipse* w = new WElipse(centro, m_RadioMayor/2, m_RadioMenor/2, m_pManager, evento.c->GetRenderer()->GetVID(), "Elipse", m_GID, evento.c);
 			m_pManager->InsertarWidget(w);
 			m_pManager->LanzarEventoCreacion(w);
 			ConsumirEvento();
@@ -180,7 +182,9 @@ GNC::GCS::Widgets::TipoCursor GNC::GCS::Widgets::WElipseBuilder::GetCursor()
 
 //region "Constructor y destructor"
 
-GNC::GCS::Widgets::WElipse::WElipse(TVector centro, TVector radio1, TVector radio2, IWidgetsManager* pManager, long vid, const char* nombre, long gid) : GNC::GCS::Widgets::IWidget(pManager, vid, nombre, gid,TID_USER_ANNOTATION_WIDGET), GNC::GCS::Widgets::IWidgetSerializable()
+GNC::GCS::Widgets::WElipse::WElipse(TVector centro, TVector radio1, TVector radio2, IWidgetsManager* pManager, long vid, const char* nombre, long gid, GNC::GCS::Contexto3D* c) : GNC::GCS::Widgets::IWidget(pManager, vid, nombre, gid,TID_USER_ANNOTATION_WIDGET), 
+	GNC::GCS::Widgets::IWidgetSerializable(),
+	m_pTextBox(NULL)
 {
 	m_Centro = centro;
 	m_RadioMayor = radio1;
@@ -195,19 +199,23 @@ GNC::GCS::Widgets::WElipse::WElipse(TVector centro, TVector radio1, TVector radi
 
 	m_Nodos = new GNC::GCS::Vector[m_NumNodos];
 
+	initTextBox(c->rotacion);
 	Recalcular();
 }
 
 GNC::GCS::Widgets::WElipse::~WElipse()
 {
 	delete[] m_Nodos;
-	LanzarEventoDestruccion();
+	m_pManager->EliminarWidget(m_pTextBox, false);
+	m_pManager->Modificado();
 }
 
 //endregion
 
 //region "Serializado y desserializado"
-GNC::GCS::Widgets::WElipse::WElipse(IWidgetsManager* pManager, long vid, long gid, wxXmlNode* nodo): GNC::GCS::Widgets::IWidget(pManager, vid,"Elipse",gid), GNC::GCS::Widgets::IWidgetSerializable(nodo)
+GNC::GCS::Widgets::WElipse::WElipse(IWidgetsManager* pManager, long vid, long gid, wxXmlNode* nodo): GNC::GCS::Widgets::IWidget(pManager, vid,"Elipse",gid), 
+	GNC::GCS::Widgets::IWidgetSerializable(nodo),
+	m_pTextBox(NULL)
 {
 	if(nodo->GetName() != wxT("elipse_widget")){
 		std::cerr<< "Ha ocurrido un error al desserializar el widget elipse"<<std::endl;
@@ -234,6 +242,8 @@ GNC::GCS::Widgets::WElipse::WElipse(IWidgetsManager* pManager, long vid, long gi
 
 	m_NodoRadioMayorReflejado = m_NodoRadioMayor.ReflejoSobrePunto(m_Centro);
 	m_NodoRadioMenorReflejado = m_NodoRadioMenor.ReflejoSobrePunto(m_Centro);
+		
+	initTextBox();
 
 	m_MouseDown = false;
 	m_UID = (long)this;
@@ -244,6 +254,24 @@ GNC::GCS::Widgets::WElipse::WElipse(IWidgetsManager* pManager, long vid, long gi
 	Recalcular();
 }
 
+void GNC::GCS::Widgets::WElipse::initTextBox(double rotation)
+{
+	if (m_pTextBox == NULL) {
+		//calculate bottom right corner to set label...
+		GNC::GCS::Vector bb[2];
+		m_NodoRadioMayor.IniciarBoundingBox(bb);
+		m_NodoRadioMayorReflejado.ExtenderBoundingBox(bb);
+		m_NodoRadioMenor.ExtenderBoundingBox(bb);
+		m_NodoRadioMenorReflejado.ExtenderBoundingBox(bb);
+
+		GNC::GCS::Vector pm = bb[0].PuntoMedio(bb[1]);
+		bb[1].RotarSobreZ( pm, rotation);
+
+		m_pTextBox = new WTextBox(m_pManager, m_VID, bb[1], WTextBox::TNM_Dynamic, "ellipse", "");
+		m_pManager->InsertarWidget(m_pTextBox);
+	}
+}
+
 wxXmlNode* GNC::GCS::Widgets::WElipse::Serializar(const std::string& nombreMedico)
 {
 	wxXmlNode* resultado = new wxXmlNode(NULL,wxXML_ELEMENT_NODE,wxT("elipse_widget"));
@@ -405,7 +433,8 @@ void GNC::GCS::Widgets::WElipse::OnMouseEvents(GNC::GCS::Events::EventoRaton& ev
 		}
 
 		if (!dentro) {
-			if (m_PosCursor.DentroDeElipse(m_Centro, m_NormaRadioMayor, m_NormaRadioMenor, m_Angulo)) {
+			if (HitTest(evento.iP.x, evento.iP.y,evento.c->RelacionImagenPantalla())) 
+			{
 				dentro = true;
 				if (evento.m_controlDown) { // Inversion de seleccion
 					InvertirSeleccion();
@@ -501,7 +530,7 @@ void GNC::GCS::Widgets::WElipse::OnMouseEvents(GNC::GCS::Events::EventoRaton& ev
 
 		if (!dentro) {
 
-			if (m_PosCursor.DentroDeElipse(m_Centro, m_NormaRadioMayor, m_NormaRadioMenor, m_Angulo)) {
+			if (HitTest(evento.iP.x, evento.iP.y,evento.c->RelacionImagenPantalla())) {
 				Iluminar(true);
 				dentro = true;
 			}
@@ -526,17 +555,22 @@ void GNC::GCS::Widgets::WElipse::OnKeyEvents(GNC::GCS::Events::EventoTeclado& ev
 	}
 }
 
-bool GNC::GCS::Widgets::WElipse::HitTest(float x, float y, const GNC::GCS::Vector& )
+bool GNC::GCS::Widgets::WElipse::HitTest(float x, float y, const GNC::GCS::Vector& threshold)
 {
 	bool dentro = true;
+	TNodo nodo(x,y);
+	float difference = 0.0f;
+	if (m_NormaRadioMayor > m_NormaRadioMenor)
+	{
+		difference = (((nodo - m_focus[0]).Norma2() + (nodo - m_focus[1]).Norma2()) - 2 * m_NormaRadioMayor);
+	} 
+	else 
+	{
+		difference = (((nodo - m_focus[0]).Norma2() + (nodo - m_focus[1]).Norma2()) - 2 * m_NormaRadioMenor);
+	}
+
+	dentro  = std::abs(difference) < (m_NodoRadioMayor.m_Size * threshold).Norma2();
 
-	if (m_NumNodos == 0) {
-		dentro = false;
-	}
-	else {
-		TNodo nodo(x,y);
-		dentro = nodo.DentroDePoligono2(m_Nodos,m_NumNodos);
-	}
 	return dentro;
 }
 
@@ -690,6 +724,19 @@ void GNC::GCS::Widgets::WElipse::Recalcular()
 
 	m_NormaRadioMayor = m_RadioMayor.Norma2();
 	m_NormaRadioMenor = m_RadioMenor.Norma2();
+	
+	//calculate focus points
+	double fDistance = sqrt(std::abs(m_NormaRadioMayor*m_NormaRadioMayor - m_NormaRadioMenor*m_NormaRadioMenor));	
+	//difference from the formula => the sum of distance from point to focus has to be = 2*bigger radious
+	if (m_NormaRadioMayor > m_NormaRadioMenor)
+	{
+		m_focus[0] = m_Centro +  m_RadioMayor.Normalizado() * fDistance;
+		m_focus[1]= m_Centro +  m_RadioMayor.Normalizado() * (-fDistance);
+	} else {
+		m_focus[0] = m_Centro +  m_RadioMenor.Normalizado() * fDistance;
+		m_focus[1] = m_Centro +  m_RadioMenor.Normalizado() * (-fDistance);
+	}
+
 	m_Angulo = m_RadioMayor.AnguloSobreAbscisa();
 
 	float step = M_2PI / m_NumNodos;
@@ -710,6 +757,17 @@ void GNC::GCS::Widgets::WElipse::Recalcular()
 
 	//std::cout << this << std::endl;
 
+	std::string text;
+	if (m_pManager->GetRendererActivo() != NULL && m_pManager->GetRendererActivo()->m_pIOverlay != NULL) {
+		text = m_pManager->GetRendererActivo()->m_pIOverlay->ImprimirOverlay(this, m_pManager->GetRendererActivo()->m_pImageViewer);
+	}
+	if (text.empty()) {
+		m_pTextBox->Ocultar(true);
+	} else {
+		m_pTextBox->Ocultar(false);
+		m_pTextBox->SetTexto(text);
+	}
+
 }
 
 void GNC::GCS::Widgets::WElipse::InsertarPropiedades(TListaMapasPropiedades &listaMapaPropiedades)
