@@ -21,6 +21,7 @@ class vtkImageData;
 namespace GNC {
 	namespace GCS {
 		namespace Widgets {
+			class WTextBox;
 			//---------------------------------------------------------------------
 
 			class WElipseBuilder : public GNC::GCS::Widgets::IWidgetBuilder {
@@ -74,7 +75,7 @@ namespace GNC {
 				typedef GNC::GCS::Events::EventoRaton TEventoRaton;
 				typedef GNC::GCS::Events::EventoTeclado TEventoTeclado;
 
-				WElipse(TVector centro, TVector radio1, TVector radio2, IWidgetsManager* pManager, long vid, const char* nombre, long gid);
+				WElipse(TVector centro, TVector radio1, TVector radio2, IWidgetsManager* pManager, long vid, const char* nombre, long gid, GNC::GCS::Contexto3D* c);
 
 				~WElipse();
 
@@ -82,6 +83,8 @@ namespace GNC {
 
 				//region "Serializado y desserializado"
 				WElipse(IWidgetsManager* pManager, long vid, long gid, wxXmlNode* nodo);
+				
+				void initTextBox(double rotation = 0.0);
 
 				wxXmlNode* Serializar(const std::string& nombreMedico);
 				//endregion
@@ -180,10 +183,12 @@ namespace GNC {
 				float   m_NormaRadioMayor;
 				float   m_NormaRadioMenor;
 				float   m_Angulo;
+				TVector m_focus[2];
 				TVector m_BB[4];
-
+				
 				float m_AreaMetrica;
-				float m_Perimetro;
+				float m_Perimetro;				
+				WTextBox*                m_pTextBox;
 
 				friend std::ostream& operator<<(std::ostream& out, const WElipse& w) {
 					out << "Elipse = [ centro = " << w.m_Centro << ", radioMayor = " << w.m_RadioMayor << ", radioMenor = " << w.m_RadioMenor << ", GID=" << w.m_GID << ", TID=" << w.m_TID << " UID=" << w.m_UID << " ]";
