@@ -19,8 +19,10 @@
 
 #include <api/globals.h>
 #include "wflecha.h"
+#include "wtextbox.h"
 #include <api/westilo.h>
 #include <api/ievento.h>
+#include <api/ioverlay.h>
 #include <api/iwidgetsrenderer.h>
 #include <api/icontexto.h>
 #include <main/managers/widgetsmanager.h>
@@ -75,7 +77,7 @@ void GNC::GCS::Widgets::WFlechaBuilder::OnMouseEvents(GNC::GCS::Events::EventoRa
 		if (m_pFlechaTemp != NULL) {
 			delete m_pFlechaTemp;
 		}
-		m_pFlechaTemp = new GNC::GCS::Widgets::WFlecha(m_pManager, evento.c->GetRenderer()->GetVID(), nodos, "Flecha");
+		m_pFlechaTemp = new GNC::GCS::Widgets::WFlecha(m_pManager, evento.c->GetRenderer()->GetVID(), nodos, evento.c, "Flecha");
 		//std::cout << "linea (leftdwn): " << m_Vertices[0].m_wX << ", " << m_Vertices[0].m_wY << " -> " << m_Vertices[1].m_wX << ", " << m_Vertices[1].m_wY << std::endl;
 		m_pManager->Modificado();
 		ConsumirEvento();
@@ -113,7 +115,9 @@ GNC::GCS::Widgets::TipoCursor GNC::GCS::Widgets::WFlechaBuilder::GetCursor()
 
 //region "Constructor y destructor"
 
-GNC::GCS::Widgets::WFlecha::WFlecha(IWidgetsManager* pManager, long vid, GNC::GCS::Nodo nodos[2], const char* nombre) : GNC::GCS::Widgets::IWidget(pManager, vid, nombre,0,TID_USER_ANNOTATION_WIDGET), GNC::GCS::Widgets::IWidgetSerializable()
+GNC::GCS::Widgets::WFlecha::WFlecha(IWidgetsManager* pManager, long vid, GNC::GCS::Nodo nodos[2], GNC::GCS::Contexto3D* c, const char* nombre) : GNC::GCS::Widgets::IWidget(pManager, vid, nombre,0,TID_USER_ANNOTATION_WIDGET),
+	GNC::GCS::Widgets::IWidgetSerializable(),
+	m_pTextBox(NULL)
 {
 	m_Vertices[0] = nodos[0];
 	m_Vertices[1] = nodos[1];
@@ -121,20 +125,22 @@ GNC::GCS::Widgets::WFlecha::WFlecha(IWidgetsManager* pManager, long vid, GNC::GC
 	m_MouseDown = false;
 	m_Oculto = false;
 
+	initTextBox(c->rotacion);
 	Recalcular();
-
 }
 
 GNC::GCS::Widgets::WFlecha::~WFlecha()
 {
-	LanzarEventoDestruccion();
-
+	m_pManager->EliminarWidget(m_pTextBox, false);
+	m_pManager->Modificado();
 }
 
 //endregion
 
 //region "Serializado y desserializado"
-GNC::GCS::Widgets::WFlecha::WFlecha(IWidgetsManager* pManager, long vid, wxXmlNode* nodo): GNC::GCS::Widgets::IWidget(pManager, vid, "Flecha"), GNC::GCS::Widgets::IWidgetSerializable(nodo)
+GNC::GCS::Widgets::WFlecha::WFlecha(IWidgetsManager* pManager, long vid, wxXmlNode* nodo): GNC::GCS::Widgets::IWidget(pManager, vid, "Flecha"), 
+	GNC::GCS::Widgets::IWidgetSerializable(nodo),
+	m_pTextBox(NULL)
 {
 	if(nodo->GetName() != wxT("flecha_widget")){
 		std::cerr<< "Ha ocurrido un error al desserializar el widget flecha"<<std::endl;
@@ -151,10 +157,26 @@ GNC::GCS::Widgets::WFlecha::WFlecha(IWidgetsManager* pManager, long vid, wxXmlNo
 	}
 
 	m_MouseDown = false;
-
+	
+	initTextBox();
 	Recalcular();
 }
 
+void GNC::GCS::Widgets::WFlecha::initTextBox(double rotation)
+{
+	if (m_pTextBox == NULL) {
+		//calculate bottom right corner to set label...
+		GNC::GCS::Vector bb[2];
+		m_Vertices[0].IniciarBoundingBox(bb);
+		m_Vertices[1].ExtenderBoundingBox(bb);
+		GNC::GCS::Vector pm = bb[0].PuntoMedio(bb[1]);
+		bb[1].RotarSobreZ( pm, rotation);
+
+		m_pTextBox = new WTextBox(m_pManager, m_VID, bb[1], WTextBox::TNM_Dynamic, "arrow", "");
+		m_pManager->InsertarWidget(m_pTextBox);
+	}
+}
+
 wxXmlNode* GNC::GCS::Widgets::WFlecha::Serializar(const std::string& nombreMedico)
 {
 	wxXmlNode* resultado = new wxXmlNode(NULL,wxXML_ELEMENT_NODE,wxT("flecha_widget"));
@@ -545,6 +567,16 @@ void GNC::GCS::Widgets::WFlecha::Recalcular()
 	m_Distancia = m_Vertices[0].DistanciaEuclidea(m_Vertices[1]);
 	//std::cout << *this << std::endl;
 
+	std::string text;
+	if (m_pManager->GetRendererActivo() != NULL && m_pManager->GetRendererActivo()->m_pIOverlay != NULL) {
+		text = m_pManager->GetRendererActivo()->m_pIOverlay->ImprimirOverlay(this, m_pManager->GetRendererActivo()->m_pImageViewer);
+	}
+	if (text.empty()) {
+		m_pTextBox->Ocultar(true);
+	} else {
+		m_pTextBox->Ocultar(false);
+		m_pTextBox->SetTexto(text);
+	}
 }
 
 void GNC::GCS::Widgets::WFlecha::OffscreenRender(GNC::GCS::Contexto3D* c)
