@@ -30,6 +30,7 @@ namespace GNC {
 		namespace Widgets {
 
 			class WFlecha;
+			class WTextBox;
 
 			class WFlechaBuilder : public GNC::GCS::Widgets::IWidgetBuilder {
 			public:
@@ -72,7 +73,7 @@ namespace GNC {
 
 				GNC::GCS::Vector m_StartPointMov;
 
-				WFlecha(IWidgetsManager* pManager, long vid, GNC::GCS::Nodo nodos[2], const char* nombre = "");
+				WFlecha(IWidgetsManager* pManager, long vid, GNC::GCS::Nodo nodos[2], GNC::GCS::Contexto3D* c, const char* nombre = "");
 
 				~WFlecha();
 
@@ -81,6 +82,8 @@ namespace GNC {
 				//region "Serializado y desserializado"
 				WFlecha(IWidgetsManager* pManager, long vid, wxXmlNode* nodo);
 
+				void initTextBox(double rotation = 0.0);
+
 				wxXmlNode* Serializar(const std::string& nombreMedico);
 
 				//endregion
@@ -176,11 +179,9 @@ namespace GNC {
 				GNC::GCS::Vector m_Diff;
 				float            m_Angulo;
 				float            m_Pendiente;
-				GNC::GCS::Vector m_TamTexto;
 
-				std::string      m_Texto;
+				WTextBox*                m_pTextBox;
 
-				GNC::GCS::TexturaCairo tc;
 
 				friend std::ostream& operator<<(std::ostream& out, const WFlecha& w) {
 					out << "[ P0=" << w.m_Vertices[0] << ", P1=" << w.m_Vertices[1] <<
