@@ -26,31 +26,27 @@ class vtkImageData;
 namespace GNC {
 	namespace GCS {
 		namespace Widgets {
+			class WTextBox;
+			class WPunto;
 
 			//---------------------------------------------------------------------
 
 			class WPuntoBuilder : public GNC::GCS::Widgets::IWidgetBuilder {
 			public:
-				WPuntoBuilder(GNC::GCS::IWidgetsManager* pManager, const GNC::GCS::TriggerButton& buttonMask, long gid, vtkImageData* pImageData = NULL);
+				WPuntoBuilder(GNC::GCS::IWidgetsManager* pManager, const GNC::GCS::TriggerButton& buttonMask, long gid);
 
 				~WPuntoBuilder();
 
 				virtual void OnMouseEvents(GNC::GCS::Events::EventoRaton&);
 
 				virtual void OnKeyEvents(GNC::GCS::Events::EventoTeclado&);
-
-				virtual void Render(GNC::GCS::Contexto3D* c);
-
+				
 				virtual GNC::GCS::Widgets::TipoCursor GetCursor();
 
+				virtual void Render(GNC::GCS::Contexto3D *);
+
 
 			protected:
-				GNC::GCS::Vector m_VerticesSeleccion[2];
-				GNC::GCS::Nodo   m_Nodo;
-				bool                      m_MouseDown;
-				Estado                   m_Estado;
-				vtkImageData*         m_pImageData;
-
 			};
 
 			//---------------------------------------------------------------------
@@ -61,6 +57,7 @@ namespace GNC {
 			private:
 				GNC::GCS::Nodo   m_Nodo;
 				GNC::GCS::Vector m_PosAntigua;
+				WTextBox*                m_pTextBox;
 
 
 			//region "Constructor y destructor"
@@ -74,6 +71,7 @@ namespace GNC {
 
 				//region "Serializado y desserializado"
 				WPunto(IWidgetsManager* pManager, long vid, long gid, wxXmlNode* nodo);
+				void initTextBox();
 
 				wxXmlNode* Serializar(const std::string& nombreMedico);
 				//endregion
@@ -90,6 +88,8 @@ namespace GNC {
 
 				virtual void Render(GNC::GCS::Contexto3D* c);
 
+				void Recalcular();
+
 				virtual void OffscreenRender(Contexto3D* c);
 
 				virtual bool SoportaAutoBorrado() const {
