@@ -19,7 +19,6 @@
 
 #include "gvistacompleja.h"
 #include "gvistasimple.h"
-#include "simpleviewexportdelegate.h"
 #include "../vistas/vista2d.h"
 #include <api/internationalization/internationalization.h>
 #include <visualizator/estudios/overlay.h>
@@ -35,6 +34,7 @@
 #include "../eventos/visualizatorevents.h"
 #include <api/controllers/icontroladorlog.h>
 #include <api/controllers/icontroladorvistas.h>
+#include <api/dicom/dcmdictionary.h>
 #include <eventos/modificacionimagen.h>
 #include <eventos/modificacionfichero.h>
 #include <eventos/modificacionwidget.h>
@@ -231,20 +231,6 @@ public:
 	}
 
 	//contrato widgets
-	vtkGinkgoImageViewer* GetViewerActivo()
-	{
-		// TODO Excepciones
-		vtkGinkgoImageViewer* viewer = GView->m_VistasSimples[0]->ViewImage2D;
-		for (GVistaCompleja::TListaGVistasSimples::iterator it = GView->m_VistasSimples.begin(); viewer == NULL && it != GView->m_VistasSimples.end(); ++it)
-		{
-			if (GView->m_pManager->GetRendererActivo() == (*it)->ViewInteractor2D)
-			{
-				viewer = (*it)->ViewImage2D;
-			}
-		}
-		return viewer;
-	}
-
 
 	GNC::GCS::IWidgetsManager* GetManager()
 	{ 
@@ -369,10 +355,6 @@ class GVistaComplejaPixelsBluringDelegate: public GNC::GCS::IPixelsBluringContra
 		~GVistaComplejaPixelsBluringDelegate()
 		{
 		}
-		vtkGinkgoImageViewer* GetViewerActivo()
-		{
-			return GView->Delegate->GetViewerActivo();
-		}
 		virtual GNC::GCS::IWidgetsManager* GetManager()
 		{ 
 			return GView->m_pManager; 
@@ -496,7 +478,6 @@ GVistaCompleja::GVistaCompleja(GNKVisualizator::Vista2D* pIVista) : VistaComplej
 	OverlaysDelegate(new GVistaComplejaOverlaysDelegate(this)),
 	WindowLayoutDelegate(new GVistaComplejaWindowLayoutDelegate(this)),
 	m_pManager (GNC::GCS::IEntorno::Instance()->NewWidgetsManager(IVista)),
-	ExportDelegate(new GNKVisualizator::SimpleViewExportContractDelegate(this)),
 	m_pPanelPreview(new GNKVisualizator::GUI::PreviewPanelVisualizator(pIVista, this)),
 	PixelsBluringDelegate(new GVistaComplejaPixelsBluringDelegate(this)),
 	AnnotatorDelegate(new GVistaComplejaAnnotatorDelegate(this, pIVista))
@@ -539,7 +520,7 @@ GVistaCompleja::GVistaCompleja(GNKVisualizator::Vista2D* pIVista) : VistaComplej
 	pToolBar->AddTool(HCore_ShowHistory, (GNC::GCS::IViewContract*) IVista);
 	pToolBar->AddTool(HCore_ColorMap, (GNC::GCS::ISliderContract*) Delegate);
 	pToolBar->AddTool(HGNKVisualizator_Overlays, OverlaysDelegate);
-	pToolBar->AddTool(HCore_ImageExport, ExportDelegate);
+	pToolBar->AddTool(HCore_ImageExport, (GNC::GCS::ISliderContract*)Delegate);
 	pToolBar->AddTool(HCore_Deshacer, (GNC::GCS::IViewContract*) IVista);
 	pToolBar->AddTool(HCore_PACSUpload, (GNC::GCS::IViewContract*) IVista);
 	pToolBar->AddTool(HCore_DicomizeFromView, (GNC::GCS::IViewContract*) IVista);
@@ -619,7 +600,10 @@ GVistaCompleja::GVistaCompleja(GNKVisualizator::Vista2D* pIVista) : VistaComplej
 
 GVistaCompleja::~GVistaCompleja()
 {
+	std::string modality("");
+	IVista->GetEstudio()->GetTagActiveImage(GKDCM_Modality, modality);
 	IVista->GetToolController()->FinalizeToolController();
+
 	IVista->ComienzaDestruccion();
 	//FUNDAMENTAL PARA QUE los viewers se destruyan correctamente y sin leaks ya que Viewer es smart pointer
 	for(TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); ++it) {
@@ -709,7 +693,6 @@ void GVistaCompleja::IniciarPipeline(const GNC::GCS::Ptr<GNC::GCS::Layout>& layo
 	m_pManager->RemoveUserAnnotationWidgets(false);
 	m_pPanelManipulacion->Enable(true);
 
-
 	GNC::GCS::Ptr<std::list<GNKVisualizator::TOverlay> > overlays(IVista->VisualizatorStudy->GetOverlaysImagenActiva());
 	OverlaysDelegate->Setup(overlays, IVista);
 	GNC::GCS::IEntorno::Instance()->GetControladorEventos()->ProcesarEvento(new GNKVisualizator::Events::EventoRefrescarListaOverlays(IVista,OverlaysDelegate->GetOverlayList()));
@@ -770,10 +753,12 @@ void GVistaCompleja::IniciarPipeline(const GNC::GCS::Ptr<GNC::GCS::Layout>& layo
 
 void GVistaCompleja::DetenerPipeline()
 {
-	m_pManager->OcultarTodosLosWidgets(true, 666);
-	m_pManager->DisableAnimation();
-	m_pPanelManipulacion->Enable(true);
-	m_pManager->Render();
+	if (m_pManager != NULL) {
+		m_pManager->OcultarTodosLosWidgets(true, 666);
+		m_pManager->DisableAnimation();
+		m_pPanelManipulacion->Enable(true);
+		m_pManager->Render();
+	}
 }
 
 void GVistaCompleja::OnCargaFinalizada()
